function [c,s]=cs_format(cs,s)
%cs_format  Funktion zur Format-Umwandlung von Kugelfunktionskoeffizienten
%
%HOW
%   [cs,s]=cs_format(cs,s)
%
%IN
%   (cs,s)  Kugelfunktionskoeffizienten
%
%OUT
%   (cs,s)  umgeordnete Kugelfunktionskoeffizienten
%
%FORMATE
%   |C\S|       (n,n)-Matrix mit Cnm auf der unteren und Snm auf der oberen
%       Dreiecksmatrix (Cn0 in der ersten Spalte, Sn1 in der ersten Zeile)
%   |/SC\|      (n,2*n)- oder (n,2*n-1)-Matrix mit Snm im rechten unteren
%       Dreieck der linken Hlfte und Cnm im linken unteren der rechten
%       (Sn0 als Nullen in der Spalte links neben der Mitte, oder fehlend)
%   |C\||S\|    Zwei (n,n)-Matrizen mit Cnm und Snm jeweils in der unteren
%       Dreiecksmatrix (Snm als (n,n-1)-Matrix bei fehlenden Sn0, sonst
%       Nullen)
%
%UMWANDLUNG
%   1 Eingabe, 1 Ausgabe:
%       |C\S|       --> |/SC\| (n,2*n-1)-Matrix
%       |/SC\|      --> |C\S|
%   2 Ausgaben:
%                   --> |C\||S\| Zwei (n,n)-Matrizen
%   2 Eingaben, 1 Ausgabe:
%       |C\||S\|    --> |C\S|
%
%Murbck Michael
%Mnchen
%12/2008

%% Eingabenberprfung

if nargin==2
    c=cs;
    [rc,cc]=size(c);
    [rs,cs]=size(s);
    if rc~=cc
        error('size(cs,1) muss gleich size(cs,2) sein')
    else
        nmax=rc-1;
    end
    if rs~=nmax+1
        error('size(s,1) muss gleich size(cs,1) sein')
    else
        switch cs 
            case rs; 
            case rs-1; s=[zeros(nmax+1,1),s];
            otherwise
                error('size(s,2) muss gleich oder um 1 kleiner als size(s,1) sein')
        end
    end
    if nargout==1
        c=c+[s(:,2:end)';zeros(1,nmax+1)];
    end
else
    [rr,cc]=size(cs);
    switch cc
        case rr
            nmax=rr-1;
            c=tril(cs);
            st=triu(cs,1)';
            s=[zeros(nmax+1,1),st(:,1:end-1)];
            if nargout==1
                c=[fliplr(s(:,2:end)),c];
            end
        case 2*rr
            nmax=rr-1;
            c=cs(:,nmax+2:end);
            s=fliplr(cs(:,1:nmax+1));
            if nargout==1
                for ro=1:nmax
                    c(ro,ro+1:end)=s(ro+1:end,ro+1)';
                end
            end
        case 2*rr-1
            nmax=rr-1;
            c=cs(:,nmax+1:end);
            s=[zeros(nmax+1,1),fliplr(cs(:,1:nmax))];
            if nargout==1
                for ro=1:nmax
                    c(ro,ro+1:end)=s(ro+1:end,ro+1)';
                end
            end
        otherwise
            error('size(cs,2) muss gleich size(cs,1) oder 2*size(cs,1) oder 2*size(cs,1)-1 sein')
    end
end
