function [scs_model_red] = reduce_normpot_grs80(scs_model,GM,ae)
% reduces GRS80 normal potential from given gravity field model 
% IN    - scs_model: gravity field model in terms of spherical harmonic coefficients in cs-format [-]
%       - GM: Earth gravity constant times Earth mass (ref. to input gravity field model) [m^3/s^2]
%       - ae: Earth radius (ref. to input gravity field model) [m] 
% OUT   - scs_model_red: disturbing potential in terms of spherical harmonic coefficients in cs-format [-]

if size(scs_model,1)~=size(scs_model,2)
    error('gravity field model must be provided in cs-format')
    return
end

nmax=size(scs_model,1)-1;
[a_grs80,GM_grs80,w,J,scs_grs80]=const_grs80(nmax);
for n=0:8
    scs_grs80(n+1,1)=scs_grs80(n+1,1)*(GM/GM_grs80)*(ae/a_grs80)^n;
end
scs_model_red=scs_model-scs_grs80();

end

function [a,GM,w,J,scs_grs80] = const_grs80(nmax)
% defining & derivable constants of grs80 

a=6378137; % m
w=7292115e-11; % rad/s
GM=3986005e8; % m^3/s^2;

J2=108263e-8;
J4=-0.00000237091222;
J6= 0.00000000608347;
J8=-0.00000000001427;

J=[J2;J4;J6;J8];

scs_grs80=zeros(nmax+1);
for i=2:2:8
    if i>nmax
        break
    end
    scs_grs80(i+1,1)=-J(i/2)/sqrt(2*i+1);
end
scs_grs80(1,1)=1;

end
